# ImageCrawler: InstagramProfile

## Purpose

A Crawler for profile pages of [https://www.instagram.com](https://www.instagram.com).

## Config

### `user_name`

- the UserName on Instagram
- type: string
- example: "justinbieber"
